@@ -23,52 +23,46 @@ from aliyunsdkdyplsapi.endpoint import endpoint_data
 class CreateAxgGroupRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Dyplsapi', '2017-05-25', 'CreateAxgGroup','dypls')
+		RpcRequest.__init__(self, 'Dyplsapi', '2017-05-25', 'CreateAxgGroup')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ResourceOwnerId(self):
+	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
-
-	def get_Numbers(self):
+	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
+		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_Numbers(self): # String
 		return self.get_query_params().get('Numbers')
 
-	def set_Numbers(self,Numbers):
-		self.add_query_param('Numbers',Numbers)
-
-	def get_Remark(self):
+	def set_Numbers(self, Numbers):  # String
+		self.add_query_param('Numbers', Numbers)
+	def get_Remark(self): # String
 		return self.get_query_params().get('Remark')
 
-	def set_Remark(self,Remark):
-		self.add_query_param('Remark',Remark)
-
-	def get_ResourceOwnerAccount(self):
+	def set_Remark(self, Remark):  # String
+		self.add_query_param('Remark', Remark)
+	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
-	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
-		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
-
-	def get_OwnerId(self):
+	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
+		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_PoolKey(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_PoolKey(self): # String
 		return self.get_query_params().get('PoolKey')
 
-	def set_PoolKey(self,PoolKey):
-		self.add_query_param('PoolKey',PoolKey)
-
-	def get_Name(self):
+	def set_PoolKey(self, PoolKey):  # String
+		self.add_query_param('PoolKey', PoolKey)
+	def get_Name(self): # String
 		return self.get_query_params().get('Name')
 
-	def set_Name(self,Name):
-		self.add_query_param('Name',Name)
\ No newline at end of file
+	def set_Name(self, Name):  # String
+		self.add_query_param('Name', Name)
