@@ -23,52 +23,46 @@ from aliyunsdkdyplsapi.endpoint import endpoint_data
 class OperateBlackNoRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Dyplsapi', '2017-05-25', 'OperateBlackNo','dypls')
+		RpcRequest.__init__(self, 'Dyplsapi', '2017-05-25', 'OperateBlackNo')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ResourceOwnerId(self):
+	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
-
-	def get_Tips(self):
+	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
+		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_Tips(self): # String
 		return self.get_query_params().get('Tips')
 
-	def set_Tips(self,Tips):
-		self.add_query_param('Tips',Tips)
-
-	def get_ResourceOwnerAccount(self):
+	def set_Tips(self, Tips):  # String
+		self.add_query_param('Tips', Tips)
+	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
-	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
-		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
-
-	def get_OwnerId(self):
+	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
+		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_PoolKey(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_PoolKey(self): # String
 		return self.get_query_params().get('PoolKey')
 
-	def set_PoolKey(self,PoolKey):
-		self.add_query_param('PoolKey',PoolKey)
-
-	def get_BlackNo(self):
+	def set_PoolKey(self, PoolKey):  # String
+		self.add_query_param('PoolKey', PoolKey)
+	def get_BlackNo(self): # String
 		return self.get_query_params().get('BlackNo')
 
-	def set_BlackNo(self,BlackNo):
-		self.add_query_param('BlackNo',BlackNo)
-
-	def get_OperateType(self):
+	def set_BlackNo(self, BlackNo):  # String
+		self.add_query_param('BlackNo', BlackNo)
+	def get_OperateType(self): # String
 		return self.get_query_params().get('OperateType')
 
-	def set_OperateType(self,OperateType):
-		self.add_query_param('OperateType',OperateType)
\ No newline at end of file
+	def set_OperateType(self, OperateType):  # String
+		self.add_query_param('OperateType', OperateType)
